@@ -53,7 +53,6 @@ import static com.openexchange.java.Autoboxing.i;
 import java.sql.Connection;
 import java.sql.SQLException;
 import java.util.Map;
-import org.apache.commons.logging.Log;
 import com.openexchange.database.DatabaseService;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.contexts.Context;
@@ -72,7 +71,7 @@ import com.openexchange.user.copy.internal.context.ContextLoadTask;
  */
 public class ConnectionFetcherTask implements CopyUserTaskService {
 
-    private static final Log LOG = com.openexchange.log.Log.loggerFor(ConnectionFetcherTask.class);
+    private static final org.slf4j.Logger LOG = org.slf4j.LoggerFactory.getLogger(ConnectionFetcherTask.class);
 
     private final DatabaseService service;
 
@@ -128,7 +127,7 @@ public class ConnectionFetcherTask implements CopyUserTaskService {
                     dstCon.commit();
                 }
             } catch (final SQLException e) {
-                LOG.error(e.getMessage(), e);
+                LOG.error("", e);
             }
             service.backForUpdateTask(dstCtxId, dstCon);
             dstCon = null;
